@@ -32,8 +32,9 @@ import configparser  # noqa
 import pickle  # noqa
 from io import StringIO  # noqa
 from shlex import quote  # noqa
-from urllib.parse import urlencode  # noqa
+from urllib.parse import urlencode, unquote  # noqa
 from urllib.request import HTTPError, HTTPSHandler, Request, build_opener  # noqa
+from collections.abc import Mapping  # noqa
 
 
 def is_string(value):
