@@ -396,7 +396,11 @@ class Run(object):
 
     def _cleanup_process(self):
         """Cleanup any leftovers from the process"""
-        pass
+        if self._process.stdout is not None and not self._process.stdout.closed:
+            try:
+                self._process.stdout.close()
+            except OSError as err:
+                self.log.raiseException("_cleanup_process: failed to close stdout of the process: %s" % err)
 
     def _read_process(self, readsize=None):
         """Read from process, return out"""
